import kotlin.math.abs
import kotlin.math.pow
import kotlin.math.sqrt

const val EPSILON = 1e-8
typealias Point = Pair<Long, Long>

fun Point.x() = first
fun Point.y() = second
data class Line(val a: Double, val b: Double, val c: Double) {
    companion object {
        fun fromPoints(left: Point, right: Point) = when {
            left.x() == right.x() -> Line(1.0, 0.0, -left.x().toDouble())
            left.y() == right.y() -> Line(0.0, 1.0, -left.y().toDouble())
            else -> {
                val dx = (left.x() - right.x()).toDouble();
                val dy = -(left.y() - right.y()).toDouble();
                Line(dy, dx, -dy * left.x() - dx * left.y())
            }
        }
    }

    fun isParallel(other: Line) = abs(a - other.a) < EPSILON && abs(b - other.b) < EPSILON
    fun isPerpendicular(other: Line) = when {
        abs(a) in 0.0..EPSILON -> b == other.a
        abs(other.a) in 0.0..EPSILON -> a == other.b
        abs(b) in 0.0..EPSILON -> a == other.b
        abs(other.b) in 0.0..EPSILON -> b == other.a
        else -> abs(abs(a / b) - abs(other.b / other.a)) < EPSILON
    }
}

fun distance(a: Point, b: Point): Double =
    sqrt((b.x() - a.x()).toDouble().pow(2) + (b.y() - a.y()).toDouble().pow(2))


fun main() {
    val (a, b, c, d) = System.`in`.bufferedReader().lineSequence().take(4).map { l ->
        l.split(" ").take(2).map { it.toLong() }.let { (a, b) -> a to b }
    }.sortedWith(Comparator.comparingLong<Point> { it.x() }.thenBy { it.y() }).toList()


    val ab = Line.fromPoints(a, b)
    val ac = Line.fromPoints(a, c)
    val ad = Line.fromPoints(a, d)
    val bc = Line.fromPoints(b, c)
    val bd = Line.fromPoints(b, d)
    val cd = Line.fromPoints(c, d)


    return when {
        /* Square
          B   D

          A   C
         */
        ab.isPerpendicular(ac) && ab.isPerpendicular(bd) && ac.isPerpendicular(cd) && bd.isPerpendicular(cd) -> when {
            abs(distance(a, b) - distance(a, c)) < EPSILON -> println("square")
            else -> println("rectangle")
        }
        
        // rhombus
        abs(distance(a, b) - distance(b, d)) < EPSILON
                && abs(distance(a, b) - distance(d, c)) < EPSILON
                && abs(distance(a, b) - distance(a, c)) < EPSILON -> println("rhombus")

        /*
            B  D   A C    B       D
          A  C       B D  A  C  B C
                             D  A
         */
        // paralelogram
        ab.isParallel(cd) && ac.isParallel(bd) -> println("parallelogram")
        ab.isParallel(cd) && ad.isParallel(bc) -> println("parallelogram")
        /* Trapezium
         BC  A  D   B      D
        A  D  BC      D  B
                    A C  A C
         */
        ad.isParallel(bc) || ab.isParallel(cd) -> println("trapezium")
        /* kite
           C       C
          A D    A     D
                   B
           B
           Diagonal either AD or BC (Cheating -> the distances should match)
         */
        abs(distance(a, c) - distance(c, d)) < EPSILON && abs(
            distance(a, b) - distance(
                b,
                d
            )
        ) < EPSILON -> println("kite")

        abs(distance(a, b) - distance(a, c)) < EPSILON && abs(
            distance(c, d) - distance(
                b,
                d
            )
        ) < EPSILON -> println("kite")

        else -> println("none")
    }

}
